@@ -1,38 +1,38 @@
 $VAR1 = {
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
-          'admin' => {
-                       'name' => 'Lindner',
-                       'password' => 'testpass',
-                       'email' => 'dirk.lze@gmail.com',
-                       'firstname' => 'Dirk'
-                     },
-          'scriptAlias' => 'cgi-bin',
-          'database' => {
-                          'CurrentDb' => 'LZE',
-                          'CurrentUser' => 'root',
-                          'CurrentPass' => 'keins',
-                          'name' => 'LZE',
-                          'user' => 'root',
-                          'host' => 'localhost',
-                          'password' => 'keins',
-                          'CurrentHost' => 'localhost'
-                        },
-          'floodtime' => 10,
-          'version' => '0.65',
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
           'language' => 'en',
-          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
           'session' => '/var/www/cgi-bin/config/session.pl',
           'cgi' => {
-                     'alias' => 'cgi-bin',
                      'serverName' => 'http://localhost',
-                     'DocumentRoot' => '/var/www/htdocs',
-                     'style' => 'mysql',
-                     'cookiePath' => '/',
-                     'bin' => '/var/www/cgi-bin',
                      'expires' => '+1y',
-                     'title' => 'MySQL::Admin'
+                     'cookiePath' => '/',
+                     'DocumentRoot' => '/var/www/htdocs',
+                     'title' => 'MySQL::Admin',
+                     'style' => 'mysql',
+                     'bin' => '/var/www/cgi-bin',
+                     'alias' => 'cgi-bin'
                    },
-          'defaultAction' => 'showLogin'
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'database' => {
+                          'CurrentUser' => 'root',
+                          'CurrentDb' => 'LZE',
+                          'CurrentPass' => 'wertvoll',
+                          'CurrentHost' => 'localhost',
+                          'user' => 'root',
+                          'host' => 'localhost',
+                          'name' => 'LZE',
+                          'password' => 'wertvoll'
+                        },
+          'version' => '0.66',
+          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'floodtime' => 10,
+          'scriptAlias' => 'cgi-bin',
+          'defaultAction' => 'showLogin',
+          'admin' => {
+                       'email' => 'dirk.lze@gmail.com',
+                       'firstname' => 'Dirk',
+                       'name' => 'Lindner',
+                       'password' => 'testpass'
+                     }
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
